<?php
/*
 * This file is part of EC-CUBE
 *
 * Copyright(c) 2000-2010 LOCKON CO.,LTD. All Rights Reserved.
 *
 * http://www.lockon.co.jp/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

// {{{ requires
require_once(CLASS_EX_REALDIR . "page_extends/admin/LC_Page_Admin_Ex.php");

/**
 * おすすめ商品管理 商品検索のページクラス.
 *
 * @package Page
 * @author LOCKON CO.,LTD.
 * @version $Id$
 */
class LC_Page_Admin_Contents_RecommendSearch extends LC_Page_Admin_Ex {

    // }}}
    // {{{ functions

    /**
     * Page を初期化する.
     *
     * @return void
     */
    function init() {
        parent::init();
        $this->tpl_mainno = 'contents';
        $this->tpl_subnavi = '';
        $this->tpl_subno = "";

    }

    /**
     * Page のプロセス.
     *
     * @return void
     */
    function process() {
        $this->action();
        $this->sendResponse();
    }

    /**
     * Page のアクション.
     *
     * @return void
     */
    function action() {
        $objDb = new SC_Helper_DB_Ex();
        $objFormParam = new SC_FormParam();
        $this->lfInitParam($objFormParam);
        $objFormParam->setParam($_POST);
        $objFormParam->convParam();

        switch ($this->getMode()) {
        case 'search':
            $objQuery = new SC_Query();
            // POST値の引き継ぎ
            $this->arrErr = $this->lfCheckError($objFormParam);
            $arrPost = $objFormParam->getHashArray();
            // 入力された値にエラーがない場合、検索処理を行う。
            // 検索結果の数に応じてページャの処理も入れる。
            if (SC_Utils_Ex::isBlank($this->arrErr)) {
                $where = 'del_flg = 0';
                $order = "update_date DESC, product_id DESC";
                list($where, $arrval) = $this->getSearchParam($objDb,$arrPost,$where);
                $linemax = $this->getLineCount($where, $arrval);
                $page_max = SC_Utils_Ex::sfGetSearchPageMax($arrPost['search_page_max']);

                // ページ送りの取得
                $objNavi = new SC_PageNavi($arrPost['search_pageno'], $linemax, $page_max, "fnNaviSearchOnlyPage", NAVI_PMAX);
                $this->tpl_linemax = $linemax;               // 何件が該当しました。表示用
                $this->tpl_strnavi = $objNavi->strnavi;      // 表示文字列
                $startno = $objNavi->start_row;

                // 取得範囲の指定(開始行番号、行数のセット)
                $objQuery->setLimitOffset($page_max, $startno);
                $objQuery->setOrder($order);
                $this->arrForm = $arrPost;
                // 検索結果の取得
                $this->arrProducts = $this->getProducts($objQuery, $arrval, $where);
            }
            break;
        default:
            break;
        }

        // カテゴリ取得
        $this->arrCatList = $objDb->sfGetCategoryList();
        $this->setTemplate('contents/recommend_search.tpl');
    }

    /**
     * デストラクタ.
     *
     * @return void
     */
    function destroy() {
        parent::destroy();
    }

    /**
     * パラメータの初期化を行う
     * @param Object $objFormParam
     */
    function lfInitParam(&$objFormParam){
        $objFormParam->addParam("商品ID", "search_name", LTEXT_LEN, "KVa", array( "MAX_LENGTH_CHECK"));
        $objFormParam->addParam("商品ID", "search_category_id", INT_LEN, "n", array( "MAX_LENGTH_CHECK","NUM_CHECK"));
        $objFormParam->addParam("商品コード", "search_product_code", LTEXT_LEN, "KVa", array( "MAX_LENGTH_CHECK"));
    }

    /**
     * 入力されたパラメータのエラーチェックを行う。
     * @param Object $objFormParam
     * @return Array エラー内容
     */
    function lfCheckError(&$objFormParam){
        $objErr = new SC_CheckError($objFormParam->getHashArray());
        $objErr->arrErr = $objFormParam->checkError();
        return $objErr->arrErr;
    }

    /**
     * 検索パラメータを返す。
     * @param Array $arrPost
     * @return Array $arrSQL 検索条件とパラメータを配列にして返す。
     */
    function getSearchParam(&$objDb,$arrPost,$where){
            $arrval = array();
            foreach ($arrPost as $key => $val) {
                if($val == "") {
                    continue;
                }
                switch ($key) {
                case 'search_name':
                    $where .= " AND name ILIKE ?";
                    $arrval[] = "%$val%";
                    break;
                case 'search_category_id':
                    list($tmp_where, $tmp_arrval) = $objDb->sfGetCatWhere($val);
                    if($tmp_where != "") {
                        $where.= " AND product_id IN (SELECT product_id FROM dtb_product_categories WHERE " . $tmp_where . ")";
                        $arrval = array_merge((array)$arrval, (array)$tmp_arrval);
                    }
                    break;
                case 'search_product_code':
                    $where .= " AND product_id IN (SELECT product_id FROM dtb_products_class WHERE product_code LIKE ? GROUP BY product_id)";
                    $arrval[] = "$val%";
                    break;
                default:
                    break;
                }
            }
            return array($where, $arrval);
    }

    /**
     * 指定された条件の商品の数を取得する
     * @param String $where 検索条件
     * @param Array $arrval 検索パラメータ
     * @return Integer $linemax 条件にマッチする商品の数
     */
    function getLineCount($where,$arrval){
        $objQuery =& SC_Query::getSingletonInstance();
        $linemax = $objQuery->count("dtb_products", $where, $arrval);
        return $linemax;
    }

    /**
     * 指定された条件の商品データを取得する。
     * @param Object $objQuery ObjQueryオブジェクト
     * @param Array $arrval 検索パラメータ
     * @param String $where 検索条件
     * @return Array 商品情報の配列
     */
    function getProducts(&$objQuery,$arrval,$where){
        $objQuery =& SC_Query::getSingletonInstance();
        return $objQuery->select("*", SC_Product::alldtlSQL(), $where, $arrval);
    }

}
?>
